@@ -6,7 +6,7 @@ from juriscraper.opinions.united_states.state import neb
 
 class Site(neb.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = (
             "https://supremecourt.nebraska.gov/courts/court-appeals/opinions"
         )
