@@ -3,7 +3,9 @@ CourtID: ri
 Court Short Name: R.I.
 Court Contact: (see ri_p)
 Author: Brian W. Carver
-Date created: 2013-08-10
+History:
+    Date created: 2013-08-10 by Brian W. Carver
+    2022-05-02: Updated by flooie, to use JSON responses
 """
 
 from juriscraper.opinions.united_states.state import ri_p
@@ -13,12 +15,6 @@ class Site(ri_p.Site):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.include_summary = False
         self.status = "Unpublished"
-        self.url = self.build_url(
-            "https://www.courts.ri.gov/Courts/SupremeCourt/Pages/Orders/Orders"
-        )
-
-    def _get_summaries(self):
-        # No summaries for unpublished, just short-circuit.
-        return None
+        self.opinion_type = "Orders"
+        self.url = self.build_url()
