@@ -5,7 +5,7 @@ from juriscraper.opinions.united_states_backscrapers.state import (
 
 class Site(idahoctapp_civil.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "http://www.isc.idaho.gov/opinions/caunpub.htm"
         self.court_id = self.__module__
 
