@@ -12,6 +12,6 @@ from juriscraper.opinions.united_states_backscrapers.state import ind
 
 class Site(ind.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = "http://www.in.gov/judiciary/opinions/archtax.html"
