@@ -1,8 +1,11 @@
 import re
-from typing import Optional
+from datetime import date, datetime
+from typing import Dict, Optional, Union
 
 import requests
 import tldextract
+from dateutil import parser
+from dateutil.tz import gettz
 from lxml import html
 
 from ..lib.exceptions import ParsingException
@@ -296,3 +299,57 @@ def get_pdf_url(court, pacer_case_id, document_number, attachment_number):
             court, pacer_case_id, document_number, attachment_number
         ),
     )
+
+
+def set_pacer_doc_id_as_appellate_document_number(
+    de: Dict[str, Union[str, date, datetime]]
+) -> None:
+    """For appellate courts that don't use numbers, if available set the
+    pacer_doc_id as document number.
+
+    :param de: The docket entry dict to set the document number.
+    :return: None, the dict is modified in place.
+    """
+    if not de["document_number"]:
+        if de["pacer_doc_id"]:
+            # If we lack the document number, but have
+            # the pacer doc ID, use it.
+            de["document_number"] = de["pacer_doc_id"]
+        else:
+            # We lack both the document number and the pacer doc ID.
+            # Probably a minute order. No need to set either.
+            pass
+
+
+def parse_datetime_for_us_timezone(datetime_str: str) -> datetime:
+    """Parse a datetime from a string that contains a US timezone.
+    :param datetime_str: The str datetime to parse.
+    :return: A datetime object with UTC timezone offset.
+    """
+
+    # Supported US timezones.
+    tzinfos = {
+        # US standard timezones
+        "EST": gettz("US/Eastern"),
+        "CST": gettz("US/Central"),
+        "MST": gettz("US/Mountain"),
+        "PST": gettz("US/Pacific"),
+        "AKST": gettz("US/Alaska"),
+        "HST": gettz("US/Hawaii"),
+        "CHST": gettz("Pacific/Guam"),
+        "SST": gettz("US/Samoa"),
+        "AST": gettz("America/Puerto_Rico"),
+        # US daylight saving time timezones
+        "EDT": gettz("US/Eastern"),
+        "CDT": gettz("US/Central"),
+        "MDT": gettz("US/Mountain"),
+        "PDT": gettz("US/Pacific"),
+        "AKDT": gettz("US/Alaska"),
+        "HDT": gettz("US/Hawaii"),
+        # CHST, SST and AST, dont' observe DST.
+    }
+    date_time = parser.parse(datetime_str, tzinfos=tzinfos)
+    if date_time.utcoffset() is None:
+        # Raise an exception if a timezone abbreviation is not specified.
+        raise NotImplementedError(f"Datetime {datetime_str} not understood.")
+    return date_time
